<?php
class EXTVS_Schedule_Posttype {
	public function __construct()
    {
		add_action( 'init', array( $this, 'register_post_type_schedule' ) );
		add_action( 'cmb2_admin_init', array( $this,'exschedule_register_metabox') );
		add_filter( 'manage_extvs_schedule_posts_columns', array( $this,'_edit_columns_tvs'),99 );
		add_action( 'manage_extvs_schedule_posts_custom_column', array( $this,'_custom_columns_content_tvs'),12);
		add_filter( 'the_title',  array( $this,'schedule_title_with_date'),10,2 );
    }
    function schedule_title_with_date($title, $id ){
    	$schedule_date = get_post_meta( $id, 'extvs_schedule_date', true );

    	$terms = get_the_terms( $id, 'extvs_channel' );            
		if ( $terms && ! is_wp_error( $terms ) ) { 
		    $channel = array();
		    foreach ( $terms as $term ) {
		        $channel[] = $term->name;
		    }                   
		    $channel = join( ", ", $channel );
		    $title = $title!='' ? $channel.' - '.$title : $channel; 
		}
		if ( $schedule_date!='' && is_numeric($schedule_date) && $schedule_date > 0 ) {
			return date_i18n(get_option('date_format'), $schedule_date).' - '.$title;
		}
	
		return $title;
    }
    function register_post_type_schedule(){
		$labels = array(
			'name'               => esc_html__('Schedule','tv-schedule'),
			'singular_name'      => esc_html__('Schedule','tv-schedule'),
			'add_new'            => esc_html__('Add New Schedule','tv-schedule'),
			'add_new_item'       => esc_html__('Add New Schedule','tv-schedule'),
			'edit_item'          => esc_html__('Edit Schedule','tv-schedule'),
			'new_item'           => esc_html__('New Schedule','tv-schedule'),
			'all_items'          => esc_html__('Schedules','tv-schedule'),
			'view_item'          => esc_html__('View Schedule','tv-schedule'),
			'search_items'       => esc_html__('Search Schedule','tv-schedule'),
			'not_found'          => esc_html__('No Schedule','tv-schedule'),
			'not_found_in_trash' => esc_html__('No Schedule in Trash','tv-schedule'),
			'parent_item_colon'  => '',
			'menu_name'          => esc_html__('TV Schedules','tv-schedule')
		);
		$args = array(  
			'labels' => $labels,  
			'supports' => array('title','custom-fields'),
			'public'             => false,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'menu_icon' =>  'dashicons-clock',
			'query_var'          => true,
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => false,
			'menu_position'      => '',
			'rewrite' => false,
		);  
		register_post_type('extvs_schedule',$args);
	}
	// Register metadata
	function exschedule_register_metabox() {
		$prefix = 'extvs_schedule_';

		/**
		 * Food general info
		 */
		$schedulue_info = new_cmb2_box( array(
			'id'            => $prefix . 'meta',
			'title'         => esc_html__( 'Schedule details', 'tv-schedule' ),
			'object_types'  => array( 'extvs_schedule' ),
		) );
		
		$schedulue_info->add_field( array(
			'name'           => esc_html__( 'Channel', 'tv-schedule' ),
			'id'             => $prefix. 'category',
			'taxonomy'       => 'extvs_channel', //Enter Taxonomy Slug
			'type'           => 'taxonomy_select',
			'remove_default' => 'true', // Removes the default metabox provided by WP core.
			// Optionally override the args sent to the WordPress get_terms function.
			'query_args' => array(
				// 'orderby' => 'slug',
				// 'hide_empty' => true,
			),
			'classes'		 => 'column-2',
			'attributes'  => array(
				'required'    => 'required',
			),
		) );
		$schedulue_info->add_field( array(
			'name' => esc_html__( 'Date', 'tv-schedule' ),
			'id'   => $prefix. 'date',
			'type' => 'text_date_timestamp',
			'classes'		 => 'column-2',
			'attributes'  => array(
				'required'    => 'required',
			),
		) );

		$addition_option = new_cmb2_box( array(
			'id'            => $prefix . 'addition_programme',
			'title'         => esc_html__( 'Additional Programme', 'tv-schedule' ),
			'object_types'  => array( 'extvs_schedule' ), // Post type
		) );
		$group_option = $addition_option->add_field( array(
			'id'          => $prefix . 'addition_data',
			'type'        => 'group',
			// 'repeatable'  => false, // use false if you want non-repeatable group
			'options'     => array(
				'group_title'   => esc_html__( 'Programme {#}', 'tv-schedule' ), // since version 1.1.4, {#} gets replaced by row number
				'add_button'    => esc_html__( 'Add Programme', 'tv-schedule' ),
				'remove_button' => esc_html__( 'Remove Programme', 'tv-schedule' ),
				'sortable'      => true, // beta
				// 'closed'     => true, // true to have the groups closed by default
			),
		) );
		$addition_option->add_group_field( $group_option, array(
			'name'       => '',
			'desc'       => '',
			'id'         => '_programme_id',
			'type'       => 'post_search_text',
			'post_type'   => 'extvs_programme',
			'select_type' => 'radio',
			'select_behavior' => 'replace',
			'classes'		 => 'extvs-add-cl',
			'before_field' => '<span class="button extvs-add-programme dashicons-search cmb2-post-search-button">'.esc_html__('Select exist Programme','tv-schedule').'</span>',
		) );
		$addition_option->add_group_field( $group_option, array(
			'name' => esc_html__( 'Time Start', 'tv-schedule' ),
			'id'   => '_time_start',
			'type' => 'text_datetime_timestamp',
			'time_format' => 'H:i',
			'classes'		 => 'column-2',
			'attributes' => array(
				'data-timepicker' => json_encode( array(
					'stepMinute' => 1,
		            'timeFormat' => 'HH:mm'
				) ),
				'required'    => 'required',
			),
		) );
		$addition_option->add_group_field( $group_option, array(
			'name' => esc_html__( 'Time End', 'tv-schedule' ),
			'id'   => '_time_end',
			'type' => 'text_datetime_timestamp',
			'time_format' => 'H:i',
			'classes'		 => 'column-2 exend_pro',
			'attributes' => array(
				'data-timepicker' => json_encode( array(
					'stepMinute' => 1,
		            'timeFormat' => 'HH:mm'
				) ),
				'required'    => 'required',
			),
		) );
		$addition_option->add_group_field( $group_option, array(
			'name' => esc_html__( 'Title', 'tv-schedule' ),
			'id'   => '_name',
			'type' => 'text',
			'attributes'  => array(
				'required'    => 'required',
			),
		) );
		$addition_option->add_group_field( $group_option, array(
			'name' => esc_html__( 'Subtitle', 'tv-schedule' ),
			'id'   => '_subtitle',
			'type' => 'text',
		) );
		$addition_option->add_group_field( $group_option, array(
			'name' => esc_html__( 'Content', 'tv-schedule' ),
			'id'   => '_content',
			'type' => 'textarea_small',
		) );
		$addition_option->add_group_field( $group_option, array(
			'name'       => esc_html__( 'Image', 'tv-schedule' ),
			'desc'       => esc_html__( 'Select featured Image', 'tv-schedule' ),
			'id'         => '_image',
			'type'       => 'file',
			'preview_size' => array( 50, 50 ),
		) );
	}

	function _edit_columns_tvs($columns){
		unset($columns['date']);
		$columns['_date'] = esc_html__( 'Date' , 'tv-schedule' );	
		return $columns;
	}
	function _custom_columns_content_tvs( $column ) {
		global $post;
		switch ( $column ) {
			case '_date':
				$_date_show = get_post_meta($post->ID, 'extvs_schedule_date', true);
				$_date_show = date_i18n(get_option('date_format'), $_date_show);
				echo '<span class="_date">'.wp_kses_post($_date_show).'</span>';
				break;	
		}
	}
	
	
}
$EXTVS_Schedule_Posttype = new EXTVS_Schedule_Posttype();