<?php
include 'inc/metadata-functions.php';
class EX_WPTVS_Posttype {
	public function __construct()
    {
        add_action( 'init', array( $this, 'register_post_type' ) );
		add_action( 'init', array( $this, 'register_programme_type_taxonomies' ) );
		add_action( 'init', array( $this, 'register_channel_taxonomies' ) );
		add_action( 'cmb2_admin_init', array( $this,'register_subtitle_fields') );
		add_action( 'edit_form_after_title', array( $this,'show_subtitle_field') );
		add_action( 'cmb2_admin_init', array( $this,'register_taxonomy_metabox') );
    }
    function register_subtitle_fields() {
		$cmb = new_cmb2_box( array(
			'id'            => 'extv_pro_subtitle',
			'object_types'  => array( 'extvs_programme' ),
		) );
		$cmb->add_field( array(
			'name' => esc_html__('Subtitle','tv-shedule'),
			'id'   => 'extv_pro_subtitle',
			'type' => 'text',
		) );
	}
	function show_subtitle_field() {
		$cmb = cmb2_get_metabox( 'extv_pro_subtitle' );
		if ( in_array( get_post_type(), $cmb->prop( 'object_types' ), 1 ) ) {
			$cmb->show_form();
		}
	}
	function register_post_type(){
		$labels = array(
			'name'               => esc_html__('Global Programme','tv-schedule'),
			'singular_name'      => esc_html__('Global Programme','tv-schedule'),
			'add_new'            => esc_html__('Add New Programme','tv-schedule'),
			'add_new_item'       => esc_html__('Add New Programme','tv-schedule'),
			'edit_item'          => esc_html__('Edit Programme','tv-schedule'),
			'new_item'           => esc_html__('New Programme','tv-schedule'),
			'all_items'          => esc_html__('Global Programme','tv-schedule'),
			'view_item'          => esc_html__('View Programme','tv-schedule'),
			'search_items'       => esc_html__('Search Programme','tv-schedule'),
			'not_found'          => esc_html__('No Programme found','tv-schedule'),
			'not_found_in_trash' => esc_html__('No Programme found in Trash','tv-schedule'),
			'parent_item_colon'  => '',
			'menu_name'          => esc_html__('TV Schedule','tv-schedule')
		);
		
		$args = array(  
			'labels' => $labels,  
			'menu_position' => 8, 
			'supports' => array('title','editor','thumbnail'),
			'public'             => false,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => 'edit.php?post_type=extvs_schedule',
			'menu_icon' =>  'dashicons-store',
			'query_var'          => true,
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => false,
			'menu_position'      => null,
		);  
		register_post_type('extvs_programme',$args);  
	}

	function register_programme_type_taxonomies(){
		$labels = array(
			'name'              => esc_html__( 'Programme category', 'tv-schedule' ),
			'singular_name'     => esc_html__( 'Programme category', 'tv-schedule' ),
			'search_items'      => esc_html__( 'Programme category','tv-schedule' ),
			'all_items'         => esc_html__( 'All Category','tv-schedule' ),
			'parent_item'       => esc_html__( 'Parent Category' ,'tv-schedule'),
			'parent_item_colon' => esc_html__( 'Parent Category:','tv-schedule' ),
			'edit_item'         => esc_html__( 'Edit Category' ,'tv-schedule'),
			'update_item'       => esc_html__( 'Update Category','tv-schedule' ),
			'add_new_item'      => esc_html__( 'Add New Category' ,'tv-schedule'),
			'menu_name'         => esc_html__( 'Category','tv-schedule' ),
		);			
		$args = array(
			'hierarchical'      => true,
			'labels'            => $labels,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'tvs-cat' ),
		);
		//version 2.0 register_taxonomy('extvs_category', array( 'extvs_programme' ), $args);
	}
	function register_channel_taxonomies(){
		$labels = array(
			'name'              => esc_html__( 'Channel', 'tv-schedule' ),
			'singular_name'     => esc_html__( 'Channel', 'tv-schedule' ),
			'search_items'      => esc_html__( 'Channel','tv-schedule' ),
			'all_items'         => esc_html__( 'All Channel','tv-schedule' ),
			'parent_item'       => esc_html__( 'Parent Channel' ,'tv-schedule'),
			'parent_item_colon' => esc_html__( 'Parent Channel:','tv-schedule' ),
			'edit_item'         => esc_html__( 'Edit Channel' ,'tv-schedule'),
			'update_item'       => esc_html__( 'Update Channel','tv-schedule' ),
			'add_new_item'      => esc_html__( 'Add New Channel' ,'tv-schedule'),
			'menu_name'         => esc_html__( 'Channel','tv-schedule' ),
		);			
		$args = array(
			'hierarchical'      => true,
			'labels'            => $labels,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'tvs-cat' ),
		);
		register_taxonomy('extvs_channel', array( 'extvs_schedule' ), $args);
	}
	function register_taxonomy_metabox() {
		$prefix = 'tvs_cn_';
		/**
		 * Metabox to add fields to categories and tags
		 */
		$cmb_term = new_cmb2_box( array(
			'id'               => $prefix . 'data',
			'title'            => esc_html__( 'Category Metabox', 'tv-schedule' ), // Doesn't output for term boxes
			'object_types'     => array( 'term' ), // Tells CMB2 to use term_meta vs post_meta
			'taxonomies'       => array( 'extvs_channel'), // Tells CMB2 which taxonomies should have these fields
			'new_term_section' => true, // Will display in the "Add New Category" section
		) );
		$cmb_term->add_field( array(
			'name' => esc_html__( 'Featured Image', 'tv-schedule' ),
			'desc' => esc_html__( 'Set featured image for this channel', 'tv-schedule' ),
			'id'   => $prefix . 'img',
			'type' => 'file',
			'options' => array(
				'url' => false, // Hide the text input for the url
			),
			'query_args' => array(
				'type' => array(
					'image/gif',
					'image/jpeg',
					'image/png',
					'image/svg',
				),
			),
			'preview_size' => array( 50, 50 ),
			'text'    => array(
				'add_upload_file_text' => esc_html__( 'Select Image', 'tv-schedule' ),
			),
		) );
	}
}
$EX_WPTVS_Posttype = new EX_WPTVS_Posttype();